# Models

## Ordinary least squares (OLS)
```{eval-rst}
.. py:currentmodule:: spycause.linear
.. autoclass: BayesOLS
    :members: 
```

## Conditional autoregressive adjustment (CAR)
```{eval-rst}
.. py:currentmodule:: spycause.linear
.. autoclass: CAR 
    :members:
```

## Intrinsic conditional autoregressive adjustment (ICAR)
```{eval-rst}
.. py:currentmodule:: spycause.linear
.. autoclass: ICAR
    :members:
```

## Joint propensity score and outcome (Joint)
```{eval-rst}
.. py:currentmodule:: spycause.linear
.. autoclass: Joint
    :members:
```
